SELECT
    UPKADP.PKPKNR AS "S_Kunde.Kunde",
    NULL AS "S_Adresse.AdressNr",
    UPKADP.PKFAAD AS "S_Adresse.Name1",
    UPKADP.PKLANR AS "S_Adresse.Staat",
    UPKADP.PKORT AS "S_Adresse.Ort",
    UPKADP.PKASOR AS "S_Adresse.Suchbegriff",
    NULL AS "S_Adresse.Selektion",
    NULL AS "S_Adresse.BriefAnrede",
    UPKADP.PKXANR AS "S_Adresse.Anrede",
    NULL AS "S_Adresse.Titel",
    NULL AS "S_Adresse.Vorname",
    UPKADP.PKADR1 AS "S_Adresse.Name2",
    UPKADP.PKADR2 AS "S_Adresse.Name3",
    UPKADP.PKPLZI AS "S_Adresse.PLZ",
    NULL AS "S_Adresse.CityPrefix",
    NULL AS "S_Adresse.CityPostfix",
    UPKADP.PKADR3 AS "S_Adresse.Strasse",
    NULL AS "S_Adresse.Hausnummer",
    UPKADP.PKKRLM AS "S_Kunde.kreditlimit",
FROM UPKADP;
