SELECT
CAST(PKPKNR AS INTEGER) as "S_Lieferant.Lieferant",
PKADR1 as "S_Adresse.Name1",
PKPLZA as "S_Adresse.Staat",
PKORT as "S_Adresse.Ort",
null as "S_Adresse.Suchbegriff",
null as "S_Adresse.Selektion",
null as "S_Adresse.BriefAnrede",
PKXANR as "S_Adresse.Anrede",
null as "S_Adresse.Titel",
null as "S_Adresse.Vorname",
PKADR2 as "S_Adresse.Name2",
null as "S_Adresse.Name3",
PKPLZI as "S_Adresse.PLZ",
null as "S_Adresse.CityPrefix",
null as "S_Adresse.CityPostfix",
null as "S_Adresse.StreetPrefix",
PKADR3 as "S_Adresse.Strasse",
null as "S_Adresse.StreetPostfix",
null as "S_Adresse.Hausnummer",
null as "S_Adresse.Bundesland",
null as "S_Adresse.PLZ_Postfach",
PKADR4 as "S_Adresse.Postfach",
null as "S_Adresse.Telefonbuch",
PKMAIL as "S_Adresse.EMail",
PKHTTP as "S_Adresse.HomePage",
null as "S_Adresse.Handy",
PKZAW1 as "S_Adresse.Telefon",
null as "S_Adresse.AutoTelefon",
PKZAW3 as "S_Adresse.Telefax",
PKZAW2 as "S_Adresse.Telefon2",
null as "S_Adresse.Telefax2",
null as "S_Adresse.Longitude",
null as "S_Adresse.Latitude",
PKASOR as "S_Lieferant.Suchbegriff",
null as "S_Lieferant.Selektion",
null as "S_Lieferant.VerteilerGruppe",
null as "S_Lieferant.Branche",
null as "S_Lieferant.Betriebskalender",
null as "S_Lieferant.Sachbearbeiter",
null as "S_Lieferant.Sprache",
null as "S_Lieferant.ABC_Klasse",
null as "S_Lieferant.Kundennummer",
PKSTNR as "S_Lieferant.inlaendische_SteuerNr",
null as "S_Lieferant.Waehrung",
null as "S_UStID.UStID",
PKZABD as "S_Lieferant.ZahlungsArt",
null as "S_Lieferant.RemittanceAdvice",
null as "S_Lieferant.ZahlungsZiel",
null as "S_Lieferant.Kreditlimit",
1 as "S_Lieferant.StGr_mit_ST",
2 as "S_Lieferant.StGr_ohne_ST",
3 as "S_Lieferant.StGrEU_mit_ST",
4 as "S_Lieferant.StGrEU_ohne_ST",
5 as "S_Lieferant.StGrAus_mit_ST",
6 as "S_Lieferant.StGrAus_ohne_ST",
null as "S_Lieferant.Lieferbedingung",
null as "S_Lieferant.VersandArt",
null as "S_Lieferant.Mindestbestellwert",
null as "BBM_WflLockStatus.BBM_WflLockStatus_ID",
null as "S_BelegParam.FormularAnzahl",
null as "S_KONTO.sammelkonto",
'yes' as "S_UStID.bestaetigt",
null as "S_BankVerb.Bankverbindung",
PKUMID as "S_UStID.IsDefault",
null as "S_Lieferant.CountryOfOrigin",
null as "S_Lieferant.RegionOfOrigin",
null as "S_Lieferant.I_BalanceList",
null as "S_Lieferant.I_NaturalPerson",
null as "S_Lieferant.I_ReportingType",
null as "S_Lieferant.I_BlackList",
null as "S_Lieferant.I_PrepaymentRate",
null as "S_Lieferant.I_PrepaymentType",
null as "S_Lieferant.CtrlGroupStateTax",
null as "S_Lieferant.CtrlGroupStateNoTax",
null as "S_Lieferant.cIN_Certificate_ImpExp",
null as "S_Lieferant.cIN_CIN",
null as "S_Lieferant.cIN_GSTID",
null as "S_Lieferant.cIN_PAN",
null as "S_Lieferant.cIN_TAN",
null as "S_Lieferant.P_Steuerregister",
null as "S_Lieferant.F_FormNrDomCur",
null as "S_Lieferant.F_FormNrForCur",
null as "S_Lieferant.F_NrForms",
null as "S_Lieferant.F_ActivitySector",
null as "S_Lieferant.F_Capital",
null as "S_Lieferant.F_Siret",
null as "S_Lieferant.F_TradeRegister",
null as "S_Lieferant.cRU_IEC",
null as "S_Lieferant.cRU_Rclassifyer",
null as "S_Lieferant.cRU_DocIdentPers",
null as "S_Lieferant.cRU_ForeignTaxID",
null as "S_Lieferant.cRU_PrimStRegNr",
null as "S_Lieferant.cRU_PrimStRegDa",
null as "S_Lieferant.cRU_EntCertRegNo",
null as "S_Lieferant.cRU_EntCerRegDate",
null as "S_Lieferant.uCW_FreeDeliveryLimit"
FROM upkadp;
