SET TERMOUT OFF
SET ECHO OFF
SET FEEDBACK OFF
SET UNDERLINE OFF
SET RECSEP OFF

SET PAGESIZE 50000
SET NEWPAGE NONE
SET LINESIZE 32767
SET TRIMSPOOL ON
SET COLSEP ';'

-- LONG / CLOB support
SET LONG 2000000000
SET LONGCHUNKSIZE 32767

SPOOL __SPOOL_PATH__

SELECT
    IK,
    SYSF,
    CREATEDA,      -- oder CREATEDATE, wenn die Spalte so heißt
    MODIFYDA,      -- dito
    CREATEUSER,
    MODIFYUSER,
    CID,
    TEXTNR,
    SPRACHE,          
    VERWENDUNG_1,
    VERWENDUNG_2,
    VERWENDUNG_3,
    VERWENDUNG_4,
    VERWENDUNG_5,
    VERWENDUNG_6,
    VERWENDUNG_7,
    VERWENDUNG_8,
    VERWENDUNG_9,
    VERWENDUNG_10,
    VERWENDUNG_11,
    VERWENDUNG_12,
    VERWENDUNG_13,
    VERWENDUNG_14,
    VERWENDUNG_15,
    VERWENDUNG_16,
    BETREFF,
    SUCHBEGRIFF,
    TEXTTYP,
    FORMAT,
    REFCOUNT,
    OLEID,
    TEXTSIZE,
    NOSQLFLD1,
    -- Long TEXT as single-line CLOB with newlines stripped
    REPLACE(
      REPLACE(TO_LOB(TEXT), CHR(13), ' '),
      CHR(10), ' '
    ) AS TEXT,
    TEXTNR_,
    BETREFF_,
    SUCHBEGRIFF_
FROM INFOR.RELTEXT
WHERE ROWNUM <= 1000;

SPOOL OFF
EXIT